//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[RegularHoraHandPattern](index.md)/[agariTatsu](agari-tatsu.md)

# agariTatsu

[common]\
val [agariTatsu](agari-tatsu.md): [Tatsu](../../mahjongutils.models/-tatsu/index.md)?

和牌搭子（为空表示单骑和牌）
